@@ -2,17 +2,15 @@ import logging
 from datetime import datetime
 from pathlib import Path
 
-from cg.constants import Workflow
 from cg.services.deliver_files.deliver_files_service.deliver_files_service import (
     DeliverFilesService,
 )
-from cg.services.deliver_files.deliver_files_service.deliver_files_service_factory import (
+from cg.services.deliver_files.factory import (
     DeliveryServiceFactory,
 )
-from cg.store.models import Case, Analysis
+from cg.store.models import Analysis, Case
 from cg.store.store import Store
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -28,8 +26,7 @@ def deliver_raw_data_for_analyses(
         try:
             case: Case = analysis.case
             delivery_service: DeliverFilesService = service_builder.build_delivery_service(
-                delivery_type=case.data_delivery,
-                workflow=Workflow.FASTQ,
+                case=case, delivery_type=case.data_delivery
             )
 
             delivery_service.deliver_files_for_case(
