@@ -5,13 +5,18 @@ from pathlib import Path
 
 from cg.constants import Workflow
 from cg.constants.constants import GenomeVersion, Strandedness
-from cg.constants.nf_analysis import MULTIQC_NEXFLOW_CONFIG, RNAFUSION_METRIC_CONDITIONS
+from cg.constants.nf_analysis import RNAFUSION_METRIC_CONDITIONS
 from cg.constants.scout import RNAFUSION_CASE_TAGS
 from cg.exc import MissingMetrics
 from cg.meta.workflow.nf_analysis import NfAnalysisAPI
+from cg.models.analysis import NextflowAnalysis
 from cg.models.cg_config import CGConfig
 from cg.models.deliverables.metric_deliverables import MetricsBase
-from cg.models.rnafusion.rnafusion import RnafusionParameters, RnafusionSampleSheetEntry
+from cg.models.rnafusion.rnafusion import (
+    RnafusionParameters,
+    RnafusionQCMetrics,
+    RnafusionSampleSheetEntry,
+)
 from cg.resources import RNAFUSION_BUNDLE_FILENAMES_PATH
 from cg.store.models import CaseSample
 
@@ -29,11 +34,14 @@ class RnafusionAnalysisAPI(NfAnalysisAPI):
     ):
         super().__init__(config=config, workflow=workflow)
         self.root_dir: str = config.rnafusion.root
-        self.nfcore_workflow_path: str = config.rnafusion.workflow_path
-        self.references: str = config.rnafusion.references
+        self.workflow_bin_path: str = config.rnafusion.workflow_bin_path
         self.profile: str = config.rnafusion.profile
         self.conda_env: str = config.rnafusion.conda_env
         self.conda_binary: str = config.rnafusion.conda_binary
+        self.platform: str = config.rnafusion.platform
+        self.params: str = config.rnafusion.params
+        self.workflow_config_path: str = config.rnafusion.config
+        self.resources: str = config.rnafusion.resources
         self.tower_binary_path: str = config.tower_binary_path
         self.tower_workflow: str = config.rnafusion.tower_workflow
         self.account: str = config.rnafusion.slurm.account
@@ -47,11 +55,6 @@ class RnafusionAnalysisAPI(NfAnalysisAPI):
         """Headers for sample sheet."""
         return RnafusionSampleSheetEntry.headers()
 
-    @property
-    def is_params_appended_to_nextflow_config(self) -> bool:
-        """Return True if parameters should be added into the nextflow config file instead of the params file."""
-        return False
-
     @property
     def is_multiple_samples_allowed(self) -> bool:
         """Return whether the analysis supports multiple samples to be linked to the case."""
@@ -61,10 +64,6 @@ class RnafusionAnalysisAPI(NfAnalysisAPI):
         """Return reference genome for a case. Currently fixed for hg38."""
         return GenomeVersion.HG38
 
-    def get_nextflow_config_content(self, case_id: str) -> str:
-        """Return nextflow config content."""
-        return MULTIQC_NEXFLOW_CONFIG
-
     @staticmethod
     def get_bundle_filenames_path() -> Path:
         """Return Rnafusion bundle filenames path."""
@@ -83,23 +82,15 @@ class RnafusionAnalysisAPI(NfAnalysisAPI):
         )
         return sample_sheet_entry.reformat_sample_content()
 
-    def get_workflow_parameters(
-        self, case_id: str, genomes_base: Path | None = None
+    def get_built_workflow_parameters(
+        self, case_id: str, dry_run: bool = False
     ) -> RnafusionParameters:
         """Get Rnafusion parameters."""
         return RnafusionParameters(
-            cluster_options=f"--qos={self.get_slurm_qos_for_case(case_id=case_id)}",
-            genomes_base=genomes_base or self.get_references_path(),
             input=self.get_sample_sheet_path(case_id=case_id),
             outdir=self.get_case_path(case_id=case_id),
-            priority=self.account,
         )
 
-    def get_references_path(self, genomes_base: Path | None = None) -> Path:
-        if genomes_base:
-            return genomes_base.absolute()
-        return Path(self.references).absolute()
-
     @staticmethod
     def ensure_mandatory_metrics_present(metrics: list[MetricsBase]) -> None:
         """Check that all mandatory metrics are present.
@@ -120,3 +111,10 @@ class RnafusionAnalysisAPI(NfAnalysisAPI):
     def get_scout_upload_case_tags(self) -> dict:
         """Return Rnafusion Scout upload case tags."""
         return RNAFUSION_CASE_TAGS
+
+    def parse_analysis(self, qc_metrics_raw: list[MetricsBase], **kwargs) -> NextflowAnalysis:
+        """Parse Nextflow output analysis files and return an analysis model."""
+        qc_metrics_model = RnafusionQCMetrics
+        return super().parse_analysis(
+            qc_metrics_raw=qc_metrics_raw, qc_metrics_model=qc_metrics_model, **kwargs
+        )
