@@ -1,6 +1,6 @@
-from typing import Any
+from typing import Annotated, Any
 
-from pydantic.v1 import validator
+from pydantic import Field, ValidationInfo, field_validator
 
 from cg.constants.subject import Sex
 from cg.models.deliverables.metric_deliverables import (
@@ -27,14 +27,15 @@ class DuplicateReads(SampleMetric):
 
     value: float
 
-    @validator("value", always=True)
+    @field_validator("value")
+    @classmethod
     def convert_duplicate_read(cls, value) -> float:
-        """Convert raw value from fraction to percent"""
+        """Convert raw value from fraction to percent."""
         return value * 100
 
 
 class SexCheck(SampleMetric):
-    """Definition of sex check metric"""
+    """Definition of sex check metric."""
 
     value: str
 
@@ -44,7 +45,8 @@ class MIPMappedReads(SampleMetric):
 
     value: float
 
-    @validator("value", always=True)
+    @field_validator("value")
+    @classmethod
     def convert_mapped_read(cls, value) -> float:
         """Convert raw value from fraction to percent"""
         return value * 100
@@ -70,34 +72,38 @@ class MIPMetricsDeliverables(MetricsDeliverables):
         "MEDIAN_TARGET_COVERAGE": MedianTargetCoverage,
         "gender": SexCheck,
     }
-    duplicate_reads: list[DuplicateReads] | None
-    mapped_reads: list[MIPMappedReads] | None
-    mean_insert_size: list[MeanInsertSize] | None
-    median_target_coverage: list[MedianTargetCoverage] | None
-    predicted_sex: list[SexCheck] | None
+    duplicate_reads: Annotated[list[DuplicateReads] | None, Field(validate_default=True)] = None
+    mapped_reads: Annotated[list[MIPMappedReads] | None, Field(validate_default=True)] = None
+    mean_insert_size: Annotated[list[MeanInsertSize] | None, Field(validate_default=True)] = None
+    median_target_coverage: Annotated[
+        list[MedianTargetCoverage] | None, Field(validate_default=True)
+    ] = None
+    predicted_sex: Annotated[list[SexCheck] | None, Field(validate_default=True)] = None
     sample_metric_to_parse: list[str] = SAMPLE_METRICS_TO_PARSE
-    sample_id_metrics: list[MIPParsedMetrics] | None
+    sample_id_metrics: Annotated[list[MIPParsedMetrics] | None, Field(validate_default=True)] = None
 
-    @validator("duplicate_reads", always=True)
-    def set_duplicate_reads(cls, _, values: dict) -> list[DuplicateReads]:
+    @field_validator("duplicate_reads")
+    @classmethod
+    def set_duplicate_reads(cls, _, info: ValidationInfo) -> list[DuplicateReads]:
         """Set duplicate_reads"""
-        return add_metric(name="fraction_duplicates", values=values)
+        return add_metric(name="fraction_duplicates", info=info)
 
-    @validator("mapped_reads", always=True)
-    def set_mapped_reads(cls, _, values: dict) -> list[MIPMappedReads]:
+    @field_validator("mapped_reads")
+    @classmethod
+    def set_mapped_reads(cls, _, info: ValidationInfo) -> list[MIPMappedReads]:
         """Set mapped reads"""
-        sample_ids: set = values.get("sample_ids")
+        sample_ids: set = info.data.get("sample_ids")
         mapped_reads: list = []
         total_sequences: dict = {}
         reads_mapped: dict = {}
-        raw_metrics: list = values.get("metrics_")
+        raw_metrics: list = info.data.get("metrics_")
         metric_step: str = ""
         for metric in raw_metrics:
             if metric.name == "raw_total_sequences":
                 raw_total_sequences = total_sequences.get(metric.id, 0)
                 total_sequences[metric.id] = int(metric.value) + raw_total_sequences
                 metric_step: str = metric.step
-            if metric.name == "reads_mapped":
+            elif metric.name == "reads_mapped":
                 raw_reads_mapped = reads_mapped.get(metric.id, 0)
                 reads_mapped[metric.id] = int(metric.value) + raw_reads_mapped
         for sample_id in sample_ids:
@@ -107,31 +113,36 @@ class MIPMetricsDeliverables(MetricsDeliverables):
             )
         return mapped_reads
 
-    @validator("mean_insert_size", always=True)
-    def set_mean_insert_size(cls, _, values: dict) -> list[MeanInsertSize]:
+    @field_validator("mean_insert_size")
+    @classmethod
+    def set_mean_insert_size(cls, _, info: ValidationInfo) -> list[MeanInsertSize]:
         """Set mean insert size"""
-        return add_metric(name="MEAN_INSERT_SIZE", values=values)
+        return add_metric(name="MEAN_INSERT_SIZE", info=info)
 
-    @validator("median_target_coverage", always=True)
-    def set_median_target_coverage(cls, _, values: dict) -> list[MedianTargetCoverage]:
+    @field_validator("median_target_coverage")
+    @classmethod
+    def set_median_target_coverage(cls, _, info: ValidationInfo) -> list[MedianTargetCoverage]:
         """Set median target coverage"""
-        return add_metric(name="MEDIAN_TARGET_COVERAGE", values=values)
+        return add_metric(name="MEDIAN_TARGET_COVERAGE", info=info)
 
-    @validator("predicted_sex", always=True)
-    def set_predicted_sex(cls, _, values: dict) -> list[SexCheck]:
+    @field_validator("predicted_sex")
+    @classmethod
+    def set_predicted_sex(cls, _, info: ValidationInfo) -> list[SexCheck]:
         """Set predicted sex"""
-        return add_metric(name="gender", values=values)
+        return add_metric(name="gender", info=info)
 
-    @validator("sample_id_metrics", always=True)
-    def set_sample_id_metrics(cls, _, values: dict) -> list[MIPParsedMetrics]:
+    @field_validator("sample_id_metrics")
+    @classmethod
+    def set_sample_id_metrics(cls, _, info: ValidationInfo) -> list[MIPParsedMetrics]:
         """Set parsed sample_id metrics gathered from all metrics"""
-        return add_sample_id_metrics(parsed_metric=MIPParsedMetrics, values=values)
+        return add_sample_id_metrics(parsed_metric=MIPParsedMetrics, info=info)
 
 
 def get_sample_id_metric(
     sample_id_metrics: list[MIPParsedMetrics], sample_id: str
 ) -> MIPParsedMetrics:
-    """Get parsed metrics for an sample_id"""
+    """Get parsed metrics for a sample id"""
     for sample_id_metric in sample_id_metrics:
         if sample_id == sample_id_metric.sample_id:
             return sample_id_metric
+    raise ValueError(f"Could not find metric for: {sample_id}")
