@@ -13,6 +13,11 @@ def filter_samples_by_internal_id(internal_id: str, samples: Query, **kwargs) ->
     return samples.filter(Sample.internal_id == internal_id)
 
 
+def filter_samples_by_internal_ids(internal_ids: list[str], samples: Query, **kwargs) -> Query:
+    """Return sample by internal id."""
+    return samples.filter(Sample.internal_id.in_(internal_ids)) if internal_ids else samples
+
+
 def filter_samples_by_name(name: str, samples: Query, **kwargs) -> Query:
     """Return sample with sample name."""
     return samples.filter(Sample.name == name)
@@ -111,14 +116,9 @@ def filter_samples_by_subject_id(samples: Query, subject_id: str, **kwargs) -> Q
     return samples.filter(Sample.subject_id == subject_id)
 
 
-def filter_samples_is_tumour(samples: Query, **kwargs) -> Query:
-    """Return samples that are tumour."""
-    return samples.filter(Sample.is_tumour.is_(True))
-
-
-def filter_samples_is_not_tumour(samples: Query, **kwargs) -> Query:
-    """Return samples that are not tumour."""
-    return samples.filter(Sample.is_tumour.is_(False))
+def filter_samples_on_tumour(samples: Query, is_tumour: bool, **kwargs) -> Query:
+    """Return samples on matching tumour status."""
+    return samples.filter(Sample.is_tumour.is_(is_tumour))
 
 
 def filter_samples_by_internal_id_pattern(
@@ -147,6 +147,12 @@ def filter_samples_by_customer(samples: Query, customer: Customer, **kwargs) ->
     return samples.filter(Sample.customer == customer)
 
 
+def filter_samples_by_customers(samples: Query, customers: list[Customer], **kwargs) -> Query:
+    """Return samples by customers."""
+    customer_ids = [customer.id for customer in customers]
+    return samples.filter(Sample.customer_id.in_(customer_ids))
+
+
 def order_samples_by_created_at_desc(samples: Query, **kwargs) -> Query:
     """Return samples ordered by created_at descending."""
     return samples.order_by(Sample.created_at.desc())
@@ -179,12 +185,14 @@ def apply_sample_filter(
     subject_id: str | None = None,
     name: str | None = None,
     customer: Customer | None = None,
+    customers: list[Customer] | None = None,
     name_pattern: str | None = None,
     internal_id_pattern: str | None = None,
     search_pattern: str | None = None,
     identifier_name: str = None,
     identifier_value: Any = None,
     limit: int | None = None,
+    is_tumour: bool | None = None,
 ) -> Query:
     """Apply filtering functions to the sample queries and return filtered results."""
 
@@ -200,12 +208,14 @@ def apply_sample_filter(
             subject_id=subject_id,
             name=name,
             customer=customer,
+            customers=customers,
             name_pattern=name_pattern,
             internal_id_pattern=internal_id_pattern,
             search_pattern=search_pattern,
             identifier_name=identifier_name,
             identifier_value=identifier_value,
             limit=limit,
+            is_tumour=is_tumour,
         )
     return samples
 
@@ -214,15 +224,18 @@ class SampleFilter(Enum):
     """Define Sample filter functions."""
 
     BY_CUSTOMER: Callable = filter_samples_by_customer
+    BY_CUSTOMERS: Callable = filter_samples_by_customers
     BY_CUSTOMER_ENTRY_IDS: Callable = filter_samples_by_entry_customer_ids
     BY_ENTRY_ID: Callable = filter_samples_by_entry_id
     BY_IDENTIFIER_NAME_AND_VALUE: Callable = filter_samples_by_identifier_name_and_value
     BY_INTERNAL_ID: Callable = filter_samples_by_internal_id
+    BY_INTERNAL_IDS: Callable = filter_samples_by_internal_ids
     BY_INTERNAL_ID_OR_NAME_SEARCH: Callable = filter_samples_by_internal_id_or_name_search
     BY_INTERNAL_ID_PATTERN: Callable = filter_samples_by_internal_id_pattern
     BY_INVOICE_ID: Callable = filter_samples_by_invoice_id
     BY_SAMPLE_NAME: Callable = filter_samples_by_name
     BY_SUBJECT_ID: Callable = filter_samples_by_subject_id
+    BY_TUMOUR: Callable = filter_samples_on_tumour
     DO_INVOICE: Callable = filter_samples_do_invoice
     HAS_NO_INVOICE_ID: Callable = filter_samples_without_invoice_id
     IS_NOT_CANCELLED: Callable = filter_out_cancelled_samples
@@ -235,8 +248,6 @@ class SampleFilter(Enum):
     IS_NOT_RECEIVED: Callable = filter_samples_is_not_received
     IS_SEQUENCED: Callable = filter_samples_is_sequenced
     IS_NOT_SEQUENCED: Callable = filter_samples_is_not_sequenced
-    IS_TUMOUR: Callable = filter_samples_is_tumour
-    IS_NOT_TUMOUR: Callable = filter_samples_is_not_tumour
     LIMIT: Callable = apply_limit
     WITH_LOQUSDB_ID: Callable = filter_samples_with_loqusdb_id
     WITHOUT_LOQUSDB_ID: Callable = filter_samples_without_loqusdb_id
